@@ -120,8 +120,6 @@ def wait_for_port(host, port, timeout=60):
 
 def find_python3():
     locations = [
-        "C:\\Python36-x64\\python.exe",
-        "C:\\Python36\\python.exe",
         "C:\\Python37-x64\\python.exe",
         "C:\\Python37\\python.exe",
         "C:\\Python38-x64\\python.exe",
@@ -138,7 +136,6 @@ def find_python3():
         except subprocess.CalledProcessError:
             continue
     names = [
-        'python3.6',
         'python3.7',
         'python3.8',
         'python3.9',
@@ -227,13 +224,9 @@ def _liveserver(clientdir, indexer_backend_option, server_executable, server_ver
     try:
         args = [
             "--serverdir", str(clientdir)]
-        if server_version >= parse_version('5.2.0.dev'):
-            init_executable = server_executable.replace(
-                "devpi-server", "devpi-init")
-            subprocess.check_call([init_executable] + args)
-        elif server_version >= parse_version('4.2.0.dev'):
-            subprocess.check_call([server_executable] + args + [
-                '--debug', '--init'])
+        init_executable = server_executable.replace(
+            "devpi-server", "devpi-init")
+        subprocess.check_call([init_executable] + args)
     except subprocess.CalledProcessError as e:
         # this won't output anything on Windows
         print(
